@@ -131,8 +131,10 @@ class Provider(AddressProvider):
             self.random_element(
                 self.secondary_address_formats))
 
-    def state(self):
+    def administrative_unit(self):
         return self.random_element(self.states)
 
+    state = administrative_unit
+
     def state_abbr(self):
         return self.random_element(self.states_abbr)
