@@ -399,12 +399,14 @@ class Provider(AddressProvider):
         """
         return self.random_element(self.cities)
 
-    def distrito(self):
+    def administrative_unit(self):
         """
         :example 'Bragança'
         """
         return self.random_element(self.distritos)
 
+    distrito = administrative_unit
+
     def concelho(self):
         """
         :example 'Tondela'
